@@ -2,8 +2,8 @@ from typing import Type
 from pydantic import BaseModel
 import abc
 from .event import BaseEvent
-from ..interfaces.dispatcher import DispatcherInterface
 from .dispatcher import BaseDispatcher
+from ..abstract.interfaces.dispatcher import IDispatcherInterface
 
 class BaseRule(metaclass=abc.ABCMeta):
     target_dispatcher: BaseDispatcher
@@ -12,12 +12,9 @@ class BaseRule(metaclass=abc.ABCMeta):
         self.target_dispatcher = target_dispatcher
 
     @abc.abstractmethod
-    def check(self, event: BaseEvent, dii: DispatcherInterface) -> bool:
+    def check(self, event: BaseEvent, dii: IDispatcherInterface) -> bool:
         pass
 
-    class Config:
-        arbitrary_types_allowed = True
-
 class SpecialEventType(BaseRule):
     target_dispatcher: BaseDispatcher
 
@@ -26,7 +23,7 @@ class SpecialEventType(BaseRule):
         self.event_type = event_type
         self.specially = specially
 
-    def check(self, event: BaseEvent, dii: DispatcherInterface) -> bool:
+    def check(self, event: BaseEvent, dii: IDispatcherInterface) -> bool:
         if self.specially:
             if type(event) is self.event_type:
                 return True
