@@ -6,18 +6,18 @@ from ..entities.decorater import Decorater
 from ..entities.signatures import Force
 from ..utilles import (is_asyncgener, iscoroutinefunction, isgeneratorfunction,
                        run_always_await_safely)
-from .dispatcher import DispatcherInterface
+from ..abstract.interfaces.dispatcher import IDispatcherInterface
 
 
 class DecoraterInterface(BaseDispatcher):
     """Graia Broadcast Control 内部机制 Decorate 的具体管理实现
     """
-    dispatcher_interface: DispatcherInterface
+    dispatcher_interface: IDispatcherInterface
     local_storage: Dict[Any, Any] = {}
     return_value: Any = None
     default = None
 
-    def __init__(self, dispatcher_interface: DispatcherInterface):
+    def __init__(self, dispatcher_interface: IDispatcherInterface):
         self.dispatcher_interface = dispatcher_interface
 
     @property
@@ -32,12 +32,12 @@ class DecoraterInterface(BaseDispatcher):
     def event(self):
         return self.dispatcher_interface.event
 
-    async def catch(self, interface: DispatcherInterface):
+    async def catch(self, interface: IDispatcherInterface):
         if isinstance(interface.default, Decorater):
             decorater: Decorater = interface.default
             if not decorater.pre:
                 # 作为 装饰
-                self.return_value = await interface.execute_with(interface.name, interface.annotation, None)
+                self.return_value = await interface.lookup_param(interface.name, interface.annotation, None)
             try:
                 # 这里隐式的复用了 dispatcher interface 的生成器终结者机制
                 if is_asyncgener(decorater.target):
